@@ -84,9 +84,10 @@ from smif.convert.area import get_register as get_region_register
 from smif.convert.area import RegionSet
 from smif.convert.interval import get_register as get_interval_register
 from smif.convert.interval import IntervalSet
+from smif.convert.unit import get_register as get_unit_register
 from smif.http_api import create_app
 from smif.parameters import Narrative
-from smif.modelrun import ModelRunBuilder
+from smif.modelrun import ModelRunBuilder, ModelRunError
 from smif.model.sos_model import SosModelBuilder
 from smif.model.sector_model import SectorModelBuilder
 from smif.model.scenario_model import ScenarioModelBuilder
@@ -150,6 +151,7 @@ LOGGER.debug('Debug logging enabled.')
 
 REGIONS = get_region_register()
 INTERVALS = get_interval_register()
+UNITS = get_unit_register()
 
 
 def setup_project_folder(args):
@@ -192,6 +194,7 @@ def load_region_sets(handler):
     region_definitions = handler.read_region_definitions()
     for region_def in region_definitions:
         region_name = region_def['name']
+        LOGGER.info("Reading in region definition %s", region_name)
         region_data = handler.read_region_definition_data(region_name)
         region_set = RegionSet(region_name, region_data)
         REGIONS.register(region_set)
@@ -208,11 +211,25 @@ def load_interval_sets(handler):
     interval_definitions = handler.read_interval_definitions()
     for interval_def in interval_definitions:
         interval_name = interval_def['name']
+        LOGGER.info("Reading in interval definition %s", interval_name)
         interval_data = handler.read_interval_definition_data(interval_name)
         interval_set = IntervalSet(interval_name, interval_data)
         INTERVALS.register(interval_set)
 
 
+def load_units(handler):
+    """Loads the units into the project registries
+
+    Parameters
+    ----------
+    handler: :class:`smif.data_layer.DataInterface`
+    """
+    unit_file = handler.read_units_file_name()
+    if unit_file is not None:
+        LOGGER.info("Loading units in from %s", unit_file)
+        UNITS.load_definitions(unit_file)
+
+
 def get_model_run_definition(args):
     """Builds the model run
 
@@ -226,6 +243,7 @@ def get_model_run_definition(args):
     handler = DatafileInterface(args.directory)
     load_region_sets(handler)
     load_interval_sets(handler)
+    load_units(handler)
 
     try:
         model_run_config = handler.read_sos_model_run(args.modelrun)
@@ -384,7 +402,12 @@ def execute_model_run(args):
 
     LOGGER.info("Running model run %s", modelrun.name)
     store = DatafileInterface(args.directory)
-    modelrun.run(store)
+
+    try:
+        modelrun.run(store)
+    except ModelRunError as ex:
+        LOGGER.exception(ex)
+        exit(1)
 
     print("Model run complete")
 
