@@ -2,11 +2,8 @@
 """
 import csv
 import os
-from collections import deque
 from csv import DictReader
-from datetime import datetime
 
-import dateutil.parser
 import fiona
 from smif.data_layer.data_interface import (DataExistsError, DataInterface,
                                             DataMismatchError,
@@ -48,6 +45,20 @@ class DatafileInterface(DataInterface):
             self.file_dir[category] = os.path.join(base_folder, folder,
                                                    category)
 
+    def read_units_file_name(self):
+        project_config = self._read_project_config()
+        filename = project_config['units']
+        self.logger.debug("Units filename is %s", filename)
+        if filename is not None:
+            path = os.path.join(self.base_folder, 'data')
+            units_file_path = os.path.join(path, filename)
+            if os.path.isfile(units_file_path):
+                return units_file_path
+            else:
+                return None
+        else:
+            return None
+
     def read_sos_model_runs(self):
         """Read all system-of-system model runs from Yaml files
 
@@ -1328,4 +1339,3 @@ class DatafileInterface(DataInterface):
         filename = filename + extension
         filepath = os.path.join(path, filename)
         dump(data, filepath)
-
