@@ -148,9 +148,9 @@ class SosModel(CompositeModel):
         list of available models and build the dependency graph
         """
         if self.free_inputs.names:
-            msg = "A SosModel must have all inputs linked to dependencies." \
-                  "Define dependencies for %s"
-            raise NotImplementedError(msg, ", ".join(self.free_inputs.names))
+            msg = "A SosModel must have all inputs linked to dependencies. " \
+                  "Define dependencies for {}"
+            raise NotImplementedError(msg.format(", ".join(self.free_inputs.names)))
 
         for model in self.models.values():
             if isinstance(model, SosModel):
@@ -179,10 +179,9 @@ class SosModel(CompositeModel):
                             dependency.source.temporal_resolution.name,
                             dependency.sink.temporal_resolution.name))
                 if dependency.source.units != dependency.sink.units:
-                    raise NotImplementedError(
-                        "Implicit units conversion not implemented (attempted {}>{})".format(
-                            dependency.source.units,
-                            dependency.sink.units))
+                    coefficient = dependency.convert(1)
+                    self.logger.debug("Implicit units conversion (%s>%s) uses coefficient %s", 
+                                    dependency.source.units, dependency.sink.units, coefficient)
 
                 self.dependency_graph.add_edge(
                     source_model,
